/*
 * Copyright (C) 2009-2010 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.deployment;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * {@code Staged} qualifies component deployment stage.
 * You can qualify the component deployment stage of your component as the 
 * following code: 
 * <pre>
 * package jazzmaster.hello;
 * 
 * import org.eiichiro.jazzmaster.deployment.Stage;
 * import org.eiichiro.jazzmaster.deployment.Staged;
 * import org.eiichiro.jazzmaster.service.Implementation;
 * 
 * {@code @Staged(Stage.TEST)}
 * {@code @Implementation}
 * public class HelloImpl implements Hello {
 * </pre>
 * This component is deployed only when the application is bootstrapped being 
 * specified with {@code Stage.TEST} stage.
 *
 * @see Stage
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface Staged {

	/** The array of stage that your component being deployed. */
	Stage[] value();
	
}
