/*
 * Copyright (C) 2009-2010 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.management;

/**
 * {@code Lifecycle} is the six lifecycle phase of the managed Jazzmaster 
 * component. These entries can be used with lifecycle callback method 
 * annotation. When a component lifecycle phase has changed, Jazzmaster 
 * component {@code Manager} invoked immediate lifecycle callback method.
 *
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
public enum Lifecycle {

	/**
	 * The phase that a component class is loaded.
	 * {@code On} annotation for this lifecycle can be detected on static method 
	 * only.
	 */
	LOADED, 
	
	/** The phase that a component instance is assembled. */
	CONFIGURED, 
	
	/** The phase that a component is started. */
	STARTED, 
	
	/** The phase that a component is stopped. */
	STOPPED, 
	
	/** The phase that a component is destroyed. */
	DESTROYED, 
	
	// The phase that a component class is unloaded.
	// {@code On} annotation for this lifecycle can be detected on static method 
	// only.
	// UNLOADED, 
	
	/** When a component lifecycle callback method is failed. */
	FAILED
	
}
