/*
 * Copyright (C) 2009-2010 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.service;

import static java.lang.annotation.ElementType.*;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.eiichiro.jazzmaster.kernel.Binding;

/**
 * {@code Typed} is a built-in {@code Binding} annotation to refer a service by 
 * service definition type ({@code Service} extension class).
 * Service (service definition or service implementation class) is automatically 
 * annotated with this binding annotation. In case of service definition, 
 * service can be referred by the type that {@code Service#getClass()} returns. 
 * If you declare a service implementation class ({@code @Implementation} 
 * annotated class), you can <b>NOT</b> refer it with the service definition 
 * type of it (because service definition class of it is anonymous). If you 
 * obviously annotate service definition or service implementation class with 
 * this binding annotation, you can also refer by the type you obviously 
 * specified with this binding annotation. But you should not do so. It is 
 * because that the service corresponding to the specified type might be 
 * duplicate.
 *
 * @see Binding
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target({FIELD, TYPE})
@Binding
public @interface Typed {

	/** The service definition type that referred by this binding annotation. */
	Class<? extends Service> value();
	
}
